package com.hzya.frame.plugin.u8c.service.impl;

import cn.hutool.core.map.MapBuilder;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.plugin.u8c.service.ISalesBillingService;
import com.hzya.frame.u8c.salesBilling.entity.U8cSalesBillingEntity;
import com.hzya.frame.u8c.salesBilling.service.IU8cSalesBillingService;
import com.hzya.frame.web.entity.BaseResult;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import java.util.List;
import java.util.Map;


public class SalesBillingServiceImpl implements ISalesBillingService {

    Logger logger = LoggerFactory.getLogger(SalesBillingServiceImpl.class);

    @Value("${OA.data_source_code}")
    private String oa_data_source_code;
    @Autowired
    private IU8cSalesBillingService iu8cSalesBillingService;

    private final String appId = "800035";
    //这个接口调错了。要用开发的那个审批接口
    //private final String apiCode = "8000350047";
    private final String apiCode = "8000350060";
    private final String publicKey = "ZJYATW/MfYZX7zF0eAh4DJXbyTLwUtwSoSz5Y/o1ksAaN/dCe7eDIk+3zDUT+v578prj";
    private final String secretKey = "+5BUkLQh3iX3VHgEt5bE2IPh+ZeebGvDaEspsvVu739Ar6sFnwg+fpPod4t6XhoTj3JzOP8MtA1LSGvL+2BWG8c/o7DKi92S4mr3zcGearA=";

    /**
     * @param requestJson
     * @return com.hzya.frame.web.entity.JsonResultEntity
     * @Author lvleigang
     * @Description 同步销售开票审核状态
     * @Date 10:21 上午 2024/8/2
     **/
    @Override
    public JsonResultEntity doSalesBilling(JSONObject requestJson) {
        //查询需要同步的数据

        try {
            U8cSalesBillingEntity u8cSalesBillingEntity = new U8cSalesBillingEntity();
            u8cSalesBillingEntity.setDataSourceCode(oa_data_source_code);
            List<U8cSalesBillingEntity> u8cSalesBillingEntities = iu8cSalesBillingService.queryDoSalesBilling(u8cSalesBillingEntity);

            if (u8cSalesBillingEntities != null && u8cSalesBillingEntities.size() > 0) {
                for (int i = 0; i < u8cSalesBillingEntities.size(); i++) {
                    U8cSalesBillingEntity entity = u8cSalesBillingEntities.get(i);
                    String params = getSendData(entity);
                    //发送数据
                    String returnData = executeEsb(params,appId,apiCode,publicKey,secretKey);
                    //解析结果
                    boolean flag = analyzeReturnData(returnData);
                    if(flag){
                        entity.setPushStatus("Y");
                    }else {
                        entity.setPushStatus("N");
                    }
                    entity.setDataSourceCode(oa_data_source_code);
                    iu8cSalesBillingService.updateDoSalesBilling(entity);
                }
                return BaseResult.getSuccessMessageEntity("同步销售开票审核状态成功");
            } else {
                return BaseResult.getSuccessMessageEntity("同步销售开票审核状态成功");
            }
        } catch (Exception e) {
            return BaseResult.getFailureMessageEntity("同步销售开票审核状态失败" + e.getMessage());
        }
    }

    /**
     * @Author lvleigang
     * @Description  解析返回状态
     * @Date 2:50 下午 2024/8/2
     * @param returnData
     * @return boolean
     **/
    private boolean analyzeReturnData(String returnData) {
        boolean falg = false ;
        if (JSONUtil.isTypeJSON(returnData)) {
            JSONObject jsonObject = JSONObject.parseObject(returnData);
            if(jsonObject != null && jsonObject.get("flag") != null && jsonObject.getBoolean("flag")) {
                JSONObject attribute = jsonObject.getJSONObject("attribute");
                if(attribute != null && attribute.get("status") != null && "success".equals(attribute.getString("status"))) {
                    falg = true;
                }
            }
        }
        return falg;
    }

    private String getSendData(U8cSalesBillingEntity entity) {
        String params = "";
        //{
        //	"queryinfo": {
        //		"code": [
        //			"SITH1904180026",
        //			"SOTH1805240023"
        //		],
        //		"corp": "1000",
        //		"date_begin": "2019-03-24",
        //		"date_end": "2019-05-24"
        //	},
        //	"approveinfo": {
        //		"approvid": "18612329914",
        //		"approveDate": "2018-04-19",
        //		"status": "Y",
        //		"note": "哈哈"
        //	}
        //}
        JSONObject data = new JSONObject();
        JSONObject queryinfo = new JSONObject();
        JSONObject approveinfo = new JSONObject();
        JSONArray code = new JSONArray();
        code.add(entity.getCode());//单据号
        queryinfo.put("code", code);
        queryinfo.put("corp", entity.getCorp());//公司编码
        queryinfo.put("date_begin", entity.getDateBegin());//单据开始日期
        queryinfo.put("date_end", entity.getDateEnd());//单据结束日期
        approveinfo.put("approvid", entity.getApprovid());//审批人
        approveinfo.put("approveDate", entity.getApprovedate());//审核时间
        approveinfo.put("status", entity.getStatus());//审批状态（Y：通过，N：不通过，R：驳回）
        approveinfo.put("note", entity.getNote());//批语

        data.put("queryinfo", queryinfo);
        data.put("approveinfo", approveinfo);
        params = data.toJSONString();

        //用新的审批接口
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("billno",entity.getCode());
        jsonObject.put("corpcode",entity.getCorp());
        jsonObject.put("billType","saleinvoice");
        jsonObject.put("userCode","15715849962");
        jsonObject.put("ckeckResult","Y");
        jsonObject.put("ckeckNote","审批通过");
        params = jsonObject.toString();
        return params;
    }


    public String executeEsb(String params, String appId, String apiCode, String publicKey, String secretKey) {
        logger.info("请求apiCode:{},参数:{}", apiCode, params);
        Map<String, String> header = MapBuilder.<String, String>create(true)
                .put("apiCode", apiCode)
                .put("publicKey", publicKey)
                .put("secretKey", secretKey)
                .put("appId", appId)
                .build();
        String res = HttpRequest.post("http://127.0.0.1:8901/kangarooDataCenterV3/entranceController/externalCallInterface").addHeaders(header).body(params).timeout(60000).execute().body();
        return res;
    }
}
