package com.hzya.frame.seeyon.receiptFor.service.impl;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.hzya.frame.basedao.service.impl.BaseService;
import com.hzya.frame.bip.v3.v2207.util.BipUtil;
import com.hzya.frame.seeyon.receiptFor.dao.IReceiptForDao;
import com.hzya.frame.seeyon.receiptFor.entity.ReceiptForEntity;
import com.hzya.frame.seeyon.receiptFor.service.IReceiptForService;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.entity.IntegrationTaskLivingDetailsEntity;
import com.hzya.frame.sysnew.integtationTaskLivingDetails.service.IIntegrationTaskLivingDetailsService;
import com.hzya.frame.web.entity.JsonResultEntity;
import org.apache.commons.collections.CollectionUtils;
import org.jetbrains.annotations.NotNull;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

@Service("ReceiptForServiceImpl")
public class ReceiptForServiceImpl extends BaseService<ReceiptForEntity,String> implements IReceiptForService {
    Logger logger = LoggerFactory.getLogger(ReceiptForServiceImpl.class);
    @Autowired
    private IReceiptForDao receiptForDao;

    @Autowired
    private IIntegrationTaskLivingDetailsService taskLivingDetailsService;

    @Override
    public JsonResultEntity sendReceiptFor(JSONObject requestJson){

        //获取重推信息id，并记录日志
        JSONObject requestJsonObj = JSON.parseObject(requestJson.toString(),JSONObject.class);
        String interId = requestJsonObj.getString("integration_task_living_details_id");
        logger.info("收款单重推解析后："+requestJsonObj.toString());
        logger.info("收款单重新执行的任务主键："+interId);

        //更换数据源
        JsonResultEntity resultEntity = new JsonResultEntity();
        ReceiptForEntity entity = new ReceiptForEntity();
        requestJson.put("db_code","djoatest");
        entity.setDataSourceCode(requestJson.getString("db_code"));

        //根据重推信息id，查询该条重推记录信息
        IntegrationTaskLivingDetailsEntity oldMsg = new IntegrationTaskLivingDetailsEntity();
        if(StrUtil.isNotEmpty(interId)){
            oldMsg = taskLivingDetailsService.get(interId);
        }
        String rootAppPk = oldMsg.getRootAppPk();
        entity.setId(rootAppPk);
        if(StrUtil.isEmpty(rootAppPk)){
            //entity.setQueryState("查询");
        }
        //如果是重推，是否通过entity传入的id，只能查到一条数据。
        //entity.setId("-8845102890648320822");
        List<ReceiptForEntity> receiptList = receiptForDao.getOaReceipt(entity);
        logger.info("收款单查询数据{}",JSONObject.toJSONString(receiptList));
        if(CollectionUtils.isNotEmpty(receiptList)){
            for(ReceiptForEntity rec : receiptList){
                try{
                    logger.info("组装数据");
                    JSONObject main = bindingAdd(rec);
                    logger.info("收款认领单推送数据："+main.toString());
                    String result = BipUtil.sendOaToU8c(main.toString(),"8000350034");
                    logger.info("收款认领单推送结果："+result);
                    IntegrationTaskLivingDetailsEntity logDetails = new IntegrationTaskLivingDetailsEntity();
                    logDetails.setRootAppPk(rec.getId());
                    logDetails.setRootAppBill(rec.getDjbh());
                    logDetails.setNewTransmitInfo(result);
                    logDetails.setNewPushDate(new Date());
                    logDetails.setRootAppNewData(JSON.toJSONString(rec));
                    logDetails.setPluginId("OaReceiptPlugin");

                    JSONObject resultObj = JSON.parseObject(result);
                    boolean flag = resultObj.get("status").equals("success");
                    if(flag){
                        // 推送成功，更新状态
                        rec.setState("Y");
                    }else{
                        // 推送失败
                        rec.setState("N");
                    }
                    rec.setDataSourceCode(requestJson.getString("db_code"));
                    try{
                        if(StrUtil.isEmpty(interId)){
                            if(flag){
                                //首推成功
                                taskLivingDetailsService.saveLogToSuccess(logDetails);
                            }else{
                                //首推失败
                                taskLivingDetailsService.saveLogToFail(logDetails);
                            }
                        }else{
                            logDetails.setId(interId);
                            if(flag){
                                //重推成功
                                taskLivingDetailsService.saveLogFailToSuccess(logDetails);
                            }else{
                                //重推失败，把失败信息，更新到重推表中
                                taskLivingDetailsService.updateLogFailToSuccess(logDetails);
                            }
                        }
                    }catch (Exception e){
                        logger.info("保存日志失败"+e.getMessage());
                        receiptForDao.updateState(rec);
                        e.printStackTrace();
                    }
                    receiptForDao.updateState(rec);
//
                } catch (Exception e) {
                    logger.info("收款单执行失败1"+e);
                    logger.info("收款单执行失败"+e.getMessage());
                    e.printStackTrace();
                }

            }
        }
        return new JsonResultEntity("成功",true,resultEntity);
    }

//    @NotNull
//    private JSONObject bindingAdd(ReceiptForEntity rec) {
//        String djrq = rec.getDjrq().substring(0,10);
//        if(djrq.length()>10){
//            djrq = rec.getDjrq().substring(0,10);
//        }
//        String shrq = rec.getShrq().substring(0,10);
//        if(shrq.length()>10){
//            shrq = rec.getShrq().substring(0,10);
//        }
//
//        JSONObject childrenJson = new JSONObject();
//        childrenJson.put("dfybje",rec.getDfybje());
//
//        childrenJson.put("dfbbje","24");
//        childrenJson.put("dfybje","12");
//        childrenJson.put("ddh","1231231");
//        childrenJson.put("fph","fph12312");
//        childrenJson.put("zy","zy");
//        childrenJson.put("bzbm_code","CNY");
//        childrenJson.put("bbhl","2");
//        childrenJson.put("contractno","hth123123");
//
//
//        JSONArray childrenArray = new JSONArray();
//        childrenArray.add(childrenJson);
//
//        JSONObject parentvo = new JSONObject();
//        parentvo.put("djrq",djrq);
//        parentvo.put("dwbm",rec.getDwbm());
//        parentvo.put("hbbm",rec.getHbbm());
//        parentvo.put("lrr",rec.getLrr());
//        parentvo.put("shr",rec.getShr());
//        parentvo.put("shrq",shrq);
//
//        JSONObject billvoJson = new JSONObject();
//        billvoJson.put("children",childrenArray);
//        billvoJson.put("parentvo",parentvo);
//
//        JSONArray billvoArray = new JSONArray();
//        billvoArray.add(billvoJson);
//        JSONObject main = new JSONObject();
//        main.put("billvo",billvoArray);
//        return main;
//    }

    @NotNull
    private JSONObject bindingAdd(ReceiptForEntity rec) {
//        if(rec.getDjrq()!=null){
//            String djrq = rec.getDjrq().substring(0,10);
//            if(djrq.length()>10){
//                djrq = rec.getDjrq().substring(0,10);
//            }
//        }
//        if(rec.getShrq()!=null){
//            String shrq = rec.getShrq().substring(0,10);
//            if(shrq.length()>10){
//                shrq = rec.getShrq().substring(0,10);
//            }
//        }

        JSONObject childrenJson = new JSONObject();
        childrenJson.put("dfybje",rec.getDfybje());

        //childrenJson.put("dfbbje",rec.getDfbbje());
        childrenJson.put("ddh",rec.getDdh());
        childrenJson.put("fph",rec.getFph());
        childrenJson.put("zy",rec.getZy());
        childrenJson.put("bzbm_code",rec.getBzbm_code());
        childrenJson.put("bbhl",rec.getBbhl());
        childrenJson.put("contractno",rec.getContractno());


        JSONArray childrenArray = new JSONArray();
        childrenArray.add(childrenJson);

        JSONObject parentvo = new JSONObject();
        parentvo.put("djrq",rec.getDjrq().substring(0,10));
        parentvo.put("dwbm",rec.getDwbm());
        parentvo.put("hbbm",rec.getHbbm());
        parentvo.put("lrr",rec.getLrr());
        parentvo.put("djlxbm",rec.getDjlxbm());//交易类型编码
        parentvo.put("shr",rec.getShr());
        parentvo.put("shrq",rec.getShrq().substring(0,10));

        parentvo.put("djbh",rec.getDjbh());
        //parentvo.put("wldx",rec.getWldx());
        parentvo.put("deptid",rec.getDeptid());
        //parentvo.put("ywybm",rec.getYwybm());
        parentvo.put("bfyhzh",rec.getBfyhzh());//本方银行账号
        parentvo.put("skyhmc",rec.getSkyhmc());//收款银行账号
        parentvo.put("pj_jsfs",rec.getPj_jsfs());//结算方式
        parentvo.put("dfyhzh",rec.getDfyhzh());//对方银行账号
        parentvo.put("scomment",rec.getScomment());//备注
        parentvo.put("zyx22",rec.getZyx22());//合同号
        parentvo.put("zyx24",rec.getZyx24());//合同名称
        parentvo.put("zyx28",rec.getZyx28());//用途
        parentvo.put("szxmid",rec.getSzxmid());//收支项目
        parentvo.put("fkyhmc",rec.getFkyhmc());
        parentvo.put("bzbm",rec.getBzbm());

        JSONObject billvoJson = new JSONObject();
        billvoJson.put("children",childrenArray);
        billvoJson.put("parentvo",parentvo);

        JSONArray billvoArray = new JSONArray();
        billvoArray.add(billvoJson);
        JSONObject main = new JSONObject();
        main.put("billvo",billvoArray);
        return main;
    }

}
